/*************************************************************************
 *
 *
 *    (c) Copyright Olimex 2010
 *
 *    File name   : LEDs_control.c
 *    Description : Functions to control the LEDs onthe board
 *
 *    History :
 *    1. Date        : 25, January 2010
 *       Author      : Aleksandar Mitev
 *       Description : Create
 *
 **************************************************************************/

#include "GenericTypeDefs.h"
#include "Compiler.h"
#include "PinManipulation.h"
#include "LEDs_control.h"

// definitions of all the LED pins
const ROM LED_PIN LED_pins[] = {
	   {GPIOA, 0},
	   {GPIOA, 1},
	   {GPIOA, 2},
	   {GPIOA, 3},
	   {GPIOC, 2},
	   {GPIOC, 1},
	   {GPIOC, 0},
  	   {GPIOA, 5}
};

const ROM int NumberOfLeds = ARRAY_NUMELEM(LED_pins);

void LED_InitializeAll(void)
{
	BYTE i;
	
	for(i = 0; i < NumberOfLeds; i++) {
		MakePinOutput( (const ROM PIN*)&LED_pins[i] );
	}
	
	LED_allOFF();
}	

void LED_allON(void)
{
	BYTE i;
	
	for(i = 0; i < NumberOfLeds; i++) {
		LED_on(i);
	}
}

void LED_allOFF(void)
{
	BYTE i;
	
	for(i = 0; i < NumberOfLeds; i++) {
		LED_off(i);
	}	
}	

void LED_on(BYTE index)
{
	if(index < NumberOfLeds) {
		ClearPin( (const ROM PIN*)&LED_pins[index] );
	}	
}	

void LED_off(BYTE index)
{
	if(index < NumberOfLeds) {
		SetPin( (const ROM PIN*)&LED_pins[index] );
	}
}	

void LED_toggle(BYTE index)
{
	if(index < NumberOfLeds) {
		if( ReadPin( (const ROM PIN*)&LED_pins[index] ) )
			LED_on(index);
		else
			LED_off(index);
	}
}



